@@ -21,7 +21,7 @@ except ImportError:
 
 
 class textEditView(QTextEdit):
-    def __init__(self, parent=None, index=None, html=None, spellcheck=True,
+    def __init__(self, parent=None, index=None, html=None, spellcheck=None,
                  highlighting=False, dict="", autoResize=False):
         QTextEdit.__init__(self, parent)
         self._column = Outline.text
@@ -39,6 +39,9 @@ class textEditView(QTextEdit):
         self._themeData = None
         self._highlighterClass = BasicHighlighter
 
+        if spellcheck is None:
+            spellcheck = settings.spellcheck
+
         self.spellcheck = spellcheck
         self.currentDict = dict if dict else settings.dict
         self._defaultFontSize = qApp.font().pointSize()
@@ -470,7 +473,7 @@ class textEditView(QTextEdit):
 
         # Check if the selected word is misspelled and offer spelling
         # suggestions if it is.
-        if cursor.hasSelection():
+        if self._dict and cursor.hasSelection():
             text = str(cursor.selectedText())
             valid = self._dict.check(text)
             selectedWord = cursor.selectedText()
